## TNDS_2021_Comp_Accross_Langs.R ##
## Programmer: Kees Schipper ##
## Created: 2021-01-13 ##
## Last Updated: 2021-01-13 ##

rm(list = ls())
dev.off()
# set up libraries --------------------------------------------------------

setwd("C:/Users/keess/Box/TNDS Workshop/R/Data")

if (!require(tidyverse)){install.packages("tidyverse")}; library(tidyverse)
if (!require(readxl)){install.packages("readxl")}; library(readxl)
if (!require(haven)){install.packages("haven")}; library(haven)
if (!require(plotrix)){install.packages("plotrix")}; library(plotrix)

# library(tidyverse)
# library(readxl)
# library(haven)
# library(plotrix)

# read in data ------------------------------------------------------------

## read in a csv file
load("workshop_data.RData")
read.csv("workshop_data.csv")
df <- workshop_data

# open the df in the environment
# describe, view, and edit data once imported -----------------------------


names(df)     # view column names of the data frames
nrow(df)      # number of rows in the data frame
ncol(df)      # number of columns in the data frame
str(df)       # shows the data structure. What types are the variables and how many obs are there

unique(df$gender)         # show unique values of gender
n_distinct(df$agedays)    # how many different ages are there
sum(complete.cases(df))   # how many completed rows are there in the df
sum(is.na(df$agedays))    # how many missing values are in a single variable


unique_vals <- lapply(df, unique)       # lapply applies a function to all columns of a df
distinct_vals <- lapply(df, n_distinct) # another example of lapply
## missing vals for each column:
missing <- lapply(df, function(x) sum(is.na(x)))
?lapply
# can even make your own function to use in lapply

# generate and label variables and observations ----------------------------

# Making a new variable in Base R:
df$ageyears = df$agedays/365.25

# let's label observations of gender with male, female, or undocumented with the factor
# function. Factor takes the "level" of the variable (which is all of the variable's
# unique values), and creates a new data type. You can also provide labels with the labels 
# argument. Levels and labels correspond to the order you entered them.
df$gender <- factor(df$gender, levels = c(-99, 0, 1), 
                    labels = c("not documented", "female", "male"))
summary(df$gender)

# let's do the same with edu level
df$edu <- factor(df$edu, levels = c(-99, 0, 1, 2, 3, 4, 5),
                 labels = c("not documented", "none", "some primary", "completed primary",
                            "some secondary", "completed secondary", "more than secondary"))
summary(df$edu)

# make summaries to estimate mean, med, range, sd -------------------------

# simple base R summary function to show mean, median, min, max
summary(df)

# individual summary functions: somewhat self-explanatory
mean(df$agemonths, na.rm = T)   # na.rm stands for "NA remove"
median(df$agemonths, na.rm = T) #
sd(df$agemonths, na.rm = T)     # standard deviation

# no explicit function for the mode of a vector, but we can make one

getmode <- function(x){ 
  # here is a small demonstration of function syntax. Don't worry about the details,
  # this is merely for demonstration of how to create user-defined functions.
  uniquev <- unique(x)
  uniquev[which.max(tabulate(match(x, uniquev)))]
}
getmode(df$agemonths)
hist(df$agemonths, breaks = 100, xlim = c(min(df$agemonths, na.rm = T), max(df$agemonths, na.rm = T)))

# tab completion to show how r makes typing functions easy
abline(v = getmode(df$agemonths), col = "red", lwd = 2)
text(x = 40, y = 200, paste0("Mode of agemonths: ", round(getmode(df$agemonths), 2)), col = "red")

range(df$agemonths, na.rm = T) # returns minimum and maximum of a vector
min(df$agemonths, na.rm = T)   
max(df$agemonths, na.rm = T)

# skewness and kurtosis are from the package "moments"
library(moments)
skewness(df$agemonths, na.rm = T) # returns skewness of a vector
kurtosis(df$agemonths, na.rm = T) # kurtosis of a vector

# here is a function for getting quantiles of a distribution. The below usage
# will return the 10th, 25th, 50th, 75th, and 90th percentiles of age in months
quantile(df$agemonths, probs = c(.10, .25, .50, .75, .90), na.rm = T)
?quantile


# frequency table with row/column percentages -----------------------------
# provide the (1) row and (2) column values top be cross tabulated
# provided data values for row and column must have the same number of observations
mytable <- table(df$gender, df$edu)
mytable

# tidyverse function for making a table of counts: just as easy
dplyr::count(df, gender, edu, sort = T)
# count(dataframe, variable, sort = T or F)

# we have already named our table values, so we don't need to label them here, but if you
# hadn't turned edu and gender into factor variables yet, here is how you would label
# table rows and columns
# rownames(mytable) <- c("missing", "male", "female")
# colnames(mytable) <- c("missing", "none", "primary school", "secondary school",
#                       "some high school", "some college", "graduate school")

# summarize table across rows
margin.table(mytable, 1)

# summarize table across columns
margin.table(mytable, 2)

# calculate row percentages 
round(prop.table(mytable, 1), 3)

# calculate column percentages
round(prop.table(mytable, 2), 3)


# Convert continuous variable to categorical ------------------------------
# in R, categorical variables are called "factors"

# tidyverse-->explore this code if you are interested
# df_cat <- df %>%
#   mutate(hfias_cat = ifelse(hfias_score < 1, 4,
#                             ifelse(hfias_score >= 1 & hfias_score < 10, 3,
#                                    ifelse(hfias_score >= 10 & hfias_score < 14, 2,
#                                           ifelse(hfias_score >= 14, 1, NA)))),
#          hfias_cat = factor(hfias_cat))

# base : create a new variable called hfias_cat from hfias_score
df$hfias_cat[df$hfias_score < 1] <- 4 # convert values of hfias_cat
df$hfias_cat[df$hfias_score >= 1 & df$hfias_score < 10] <- 3
df$hfias_cat[df$hfias_score >= 10 & df$hfias_score < 14] <- 2
df$hfias_cat[df$hfias_score >= 14] <- 1

summary(df$hfias_cat)

# turn this variable into a factor
df$hfias_cat <- as.factor(df$hfias_cat)

# show the new variable
summary(df$hfias_cat)

save(df, file = "../output/output_df.RData")
# or 
write.csv(df, "../output/output_df.csv")


# Comparison tests and measures of association ----------------------------

# we want to remove values that don't have data on gender in our dataset
df_ttest <- df[df$gender == "female" | df$gender == "male",]

# t test with assumption of unequal variance
t.test(df_ttest$av_len ~ df_ttest$gender, conf.level = 0.95, paired = FALSE, var.equal = FALSE)

# wilcox test with option of a Fischer's exact test (exact = T), while applying a 
# continuity correction (correct = T)
wilcox.test(df_ttest$av_len ~ df_ttest$gender, conf.int = T, conf.level = 0.95, exact = F,
            correct = T)

# running code to make a pearson (parametric) correlation coefficient
p_corr <- cor(df$av_weight, df$av_len, use = "complete.obs", method = c("pearson"))
# and code to make a spearman (non-parametric) correlation coefficient
s_corr <- cor(df$av_weight, df$av_len, use = "complete.obs", method = c("spearman"))
p_corr # 0.9449736
s_corr # 0.9309364

# for this data, we can see that spearman and pearson correlation coefficients are very similar

# Simple linear or simple logistic regression -----------------------------

# keeping only rows from our data frame with complete information on all variables
df_mod <- df[complete.cases(df),]

# lm() is the function for linear models. Here we regress average length on average weight
# and specify our data with the data argument
length_model <- lm(av_len ~ av_weight, data = df_mod)
# view your model parameters with the summary function
summary(length_model)

# can use the "predict" function to get confidence and prediction intervals over your
# models. Specify if you want confidence or prediction intervals, and the level that
# you want your intervals to adhere to
pred_ints <- predict(length_model, interval = "prediction", level = 0.95)

conf_ints <- predict(length_model, interval = "confidence", level = 0.99)

# can plot your raw data, linear model, confidence, and prediction intervals on the same
# plot using the below sequence
plot(df_mod$av_weight, df_mod$av_len, main = "Plot of Average Length vs. Average weight")
abline(length_model, col = "red", lwd = 3)
lines(df_mod$av_weight, pred_ints[,2], col = "skyblue", lty = 2) 
lines(df_mod$av_weight, pred_ints[,3], col = "skyblue", lty = 2)
lines(df_mod$av_weight, conf_ints[,2], col = "blue", lty = 3)
lines(df_mod$av_weight, conf_ints[,3], col = "blue", lty = 3)

# the "lines" function adds a plot line on top of your current plot.
# the abline function does the same thing, but also lets you specify a model to fit

# for future reference: stop around here
# Multivariable regression with continuous and categorical vars -----------

library(car)
library(MASS)
library(corrplot)

# cool correaltion plot to explore the relationship between variables
# corrplot(cor(df_mod[c("av_len", "av_weight", "hfias_score", "av_muac")]))

mv_length_model <- lm(av_len ~ av_weight + gender + edu + hfias_score + av_muac, data = df_mod)
summary(mv_length_model)

## to check linear model assumptions
vif(mv_length_model) # variance inflation factor
plot(mv_length_model) # plots residuals vs fitted, normal q-q, cook's distance, and std residuals
crPlots(mv_length_model, terms = ~av_weight + hfias_score + av_muac, smooth = T)
# shows the smoothed relationship of each variable with the outcome





